==> kubernetes-model-core-5.0.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/ConfigMapVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigMapVolumeSourceBuilder extends ConfigMapVolumeSourceFluentImpl<ConfigMapVolumeSourceBuilder> implements VisitableBuilder<ConfigMapVolumeSource,ConfigMapVolumeSourceBuilder> {

    ConfigMapVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigMapVolumeSourceBuilder() {
        this(true);
    }

    public ConfigMapVolumeSourceBuilder(Boolean validationEnabled) {
        this(new ConfigMapVolumeSource(), validationEnabled);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent) {
        this(fluent, true);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ConfigMapVolumeSource(), validationEnabled);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,ConfigMapVolumeSource instance) {
        this(fluent, instance, true);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,ConfigMapVolumeSource instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withDefaultMode(instance.getDefaultMode()); 
        fluent.withItems(instance.getItems()); 
        fluent.withName(instance.getName()); 
        fluent.withOptional(instance.getOptional()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSource instance) {
        this(instance,true);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSource instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withDefaultMode(instance.getDefaultMode()); 
        this.withItems(instance.getItems()); 
        this.withName(instance.getName()); 
        this.withOptional(instance.getOptional()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigMapVolumeSource build() {
        ConfigMapVolumeSource buildable = new ConfigMapVolumeSource(fluent.getDefaultMode(),fluent.getItems(),fluent.getName(),fluent.isOptional());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ConfigMapVolumeSourceBuilder that = (ConfigMapVolumeSourceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/ConfigMapVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigMapVolumeSourceBuilder extends ConfigMapVolumeSourceFluentImpl<ConfigMapVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<ConfigMapVolumeSource,ConfigMapVolumeSourceBuilder> {

    ConfigMapVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigMapVolumeSourceBuilder() {
        this(true);
    }

    public ConfigMapVolumeSourceBuilder(Boolean validationEnabled) {
        this(new ConfigMapVolumeSource(), validationEnabled);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent) {
        this(fluent, true);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ConfigMapVolumeSource(), validationEnabled);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,ConfigMapVolumeSource instance) {
        this(fluent, instance, true);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,ConfigMapVolumeSource instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withDefaultMode(instance.getDefaultMode()); 
        fluent.withItems(instance.getItems()); 
        fluent.withName(instance.getName()); 
        fluent.withOptional(instance.getOptional()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSource instance) {
        this(instance,true);
    }

    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSource instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withDefaultMode(instance.getDefaultMode()); 
        this.withItems(instance.getItems()); 
        this.withName(instance.getName()); 
        this.withOptional(instance.getOptional()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigMapVolumeSource build() {
        ConfigMapVolumeSource buildable = new ConfigMapVolumeSource(fluent.getDefaultMode(),fluent.getItems(),fluent.getName(),fluent.getOptional());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ConfigMapVolumeSourceBuilder that = (ConfigMapVolumeSourceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
